<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <link href="{{ '/assets/css/style.css?v=' | append: site.github.build_revision | relative_url }}" rel="stylesheet">
    {% seo %}
  </head>
  <body>
    <div class="container markdown-body">
      <h1>{{ site.title }}</h1>
      
      {{ content }}
    </div>
    <script src="{{ "assets/javascript/anchor-js/anchor.min.js" | relative_url }}"></script>
    <script>anchors.add();</script>
  </body>
</html>
